==> nextcloud-app-calendar-1.5.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/pl.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendarz",
    "%s has published the calendar »%s«" : "%s opublikował kalendarz »%s«",
    "Hello," : "Witaj,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chcieliśmy poinformować, że %s opublikował kalendarz %s.",
    "Open »%s«" : "Otwórz »%s«",
    "Cheers!" : "Zdrówko!",
    "Recipient" : "Odbiorca",
    "Too many redirects. Aborting ..." : "Za dużo przekierowań. Przerywam...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Brak dostępu do kalendarza na zdalnym serwerze (HTTP {%s} error)",
    "Error connecting to remote server" : "Błąd podczas łączenia się z serwerem zdalnym",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Błąd żądania zasobu na zdalnym serwerze. Możliwe, że może to być związane z niedopasowaniem certyfikatu",
    "Error requesting resource on remote server" : "Błąd żądania zasobów na zdalnym serwerze",
    "Individual" : "Indywidualny",
    "Group" : "Grupa",
    "Resource" : "Zasób",
    "Room" : "Pokój",
    "Unknown" : "Nieznany",
    "Required" : "Wymagany",
    "Optional" : "Opcjonalny",
    "Does not attend" : "Nie uczestniczy",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jesteś w nieznanej strefie czasowej ({tz}), powracam do UTC",
    "Please create a calendar first." : "Proszę najpierw utworzyć kalendarz.",
    "New event" : "Nowe zdarzenie",
    "CalDAV address for clients" : "Adres CalDAV dla klientów",
    "Error saving WebCal-calendar" : "Błąd podczas zapisywania kalendarza WebCal",
    "WebDAV address for subscriptions" : "Adres WebDAV dla subskrypcji",
    "Email has been sent." : "E-mail został wysłany.",
    "There was an issue while sending your email." : "Wystąpił problem podczas wysyłania e-maila.",
    "group" : "grupa",
    "Details" : "Szczegóły",
    "Attendees" : "Uczestnicy",
    "Reminders" : "Przypomnienia",
    "Repeating" : "Powtarzające się",
    "When shared show full event" : "Kiedy współdzieli pokaż całe wydarzenie",
    "When shared show only busy" : "Kiedy współdzieli pokaż tylko zajęty",
    "When shared hide this event" : "Kiedy współdzieli ukryj to wydarzenie",
    "Confirmed" : "Potwierdzone",
    "Tentative" : "Możliwe",
    "Cancelled" : "Przerwano",
    "Please add a title." : "Dodaj tytuł.",
    "Please select a calendar." : "Wybierz kalendarz.",
    "The event can not end before it starts." : "Wydarzenie nie może kończyć się zanim się rozpocznie.",
    "Global" : "Ogólny",
    "None" : "Brak.",
    "Every day" : "Codziennie",
    "Every week" : "Co tydzień",
    "Every month" : "Co miesiąc",
    "Every year" : "Co roku",
    "never" : "nigdy",
    "after" : "po",
    "How about getting started by importing some calendars?" : "Czy rozpocząć pracę przez importowanie kilku kalendarzy?",
    "At time of event" : "W momencie zdarzenia",
    "5 minutes before" : "5 minut przed",
    "10 minutes before" : "10 minut przed",
    "15 minutes before" : "15 minut przed",
    "30 minutes before" : "30 minut przed",
    "1 hour before" : "1 godzinę przed",
    "2 hours before" : "2 godziny przed",
    "Custom" : "Dowolnie",
    "Audio" : "Dźwięk",
    "Email" : "E-mail",
    "Pop-up" : "Pop-up",
    "sec" : "sek",
    "min" : "min",
    "hours" : "godzin",
    "days" : "dniach",
    "week" : "tydzień",
    "before" : "przed",
    "start" : "rozpocznij",
    "end" : "zakończ",
    "Editing reminders of unknown type not supported." : "Edycja przypomnień nieznanego typu nie jest wspierana.",
    "Week {number} of {year}" : "{number}. tydzień {year}",
    "{type} {time} before the event starts" : "{type} {time} przed rozpoczęciem wydarzenia",
    "{type} {time} before the event ends" : "{type} {time} przed zakończeniem wydarzenia",
    "{type} {time} after the event starts" : "{type} {time} po rozpoczęciu wydarzenia",
    "{type} {time} after the event ends" : "{type} {time} po zakończeniu wydarzenia",
    "{type} at the event's start" : "{type} na początku wydarzenia",
    "{type} at the event's end" : "{type} na końcu wydarzenia",
    "{type} at {time}" : "{type} o {time}",
    "{calendar} shared by {owner}" : "{calendar} współdzielony przez {owner}",
    "Please enter a valid WebCal-URL" : "Wprowadź prawidłowy URL WebCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Poważny błąd proxy w WebCal. Aby uzyskać więcej informacji prosimy o kontakt z administratorem.",
    "Title of the Event" : "Nazwa wydarzenia",
    "Starts" : "Zaczyna się",
    "Ends" : "Kończy się",
    "All day Event" : "Wydarzenie całodniowe",
    "Delete" : "Usuń",
    "Cancel" : "Anuluj",
    "More ..." : "Więcej...",
    "Create" : "Utwórz",
    "Update" : "Aktualizuj",
    "Close" : "Zamknij",
    "Location" : "Lokalizacja",
    "Description" : "Opis",
    "Event status" : "Status zdarzenia",
    "Visibility when sharing" : "Widoczność podczas współdzielenia",
    "Export" : "Eksportuj",
    "%s has published the calendar %s" : "%s opublikował/-a kalendarz %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chcieliśmy poinformować, że %s opublikował/-a kalendarz {boldstart}%s{boldend}.",
    "Click here to access it" : "Kliknij tutaj, aby uzyskać dostęp do niego",
    "We wanted to inform you that %s has published the calendar %s." : "Chcieliśmy poinformować, że %s opublikował/-a kalendarz %s.",
    "Click on the link below to access it" : "Kliknij na link poniżej, aby uzyskać do niego dostęp",
    "Day" : "Dzień",
    "Week" : "Tydzień",
    "Month" : "Miesiąc",
    "Today" : "Dziś",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Niektóre zdarzenia w tym kalendarzu są uszkodzone. Proszę sprawdzić konsole JS, aby dowiedzieć się więcej.",
    "Share Calendar" : "Współdziel kalendarz",
    "Shared" : "Udostępniono",
    "More" : "Więcej",
    "Edit" : "Edytuj",
    "Link" : "Link",
    "iCal link" : "Łącze iCal",
    "Download" : "Pobierz",
    "Share with users or groups" : "Współdziel z grupami bądź użytkownikami",
    "can edit" : "może edytować",
    "Share link" : "Udostępnij link",
    "Public access" : "Dostęp publiczny",
    "Email link to person" : "Wyślij wiadomość do osoby",
    "Send" : "Wysłać",
    "New Calendar" : "Nowy kalendarz",
    "Name" : "Nazwa",
    "New Subscription" : "Nowa subskrypcja",
    "Go back" : "Wróć",
    "Go forward" : "Naprzód",
    "Calendar does not exist" : "Kalendarz nie istnieje",
    "Maybe you got a wrong link or the calendar was unshared?" : "Być może link jest nieprawidłowy lub kalendarz przestał być współdzielony.",
    "Edit event" : "Edytuj zdarzenie",
    "Delete Event" : "Usuń zdarzenie",
    "Save Event" : "Zapisz zdarzenie",
    "Time" : "Czas",
    "Type" : "Typ",
    "Relative" : "Pokrewny",
    "Absolute" : "Całkowity",
    "Repeat" : "Powtarzaj",
    "times every" : "razy w każdy",
    "Add" : "Dodaj",
    "Email address of attendee" : "Adres e-mail uczestnika",
    "Please add your email address in the personal settings in order to add attendees." : "Aby dodać uczestników, proszę ustawić adres e-mail w ustawieniach konta.",
    "from" : "z",
    "to" : "do",
    "This event's repeating rule is not supported yet." : "Ta reguła powtarzania wydarzenia nie jest jeszcze wspierana.",
    "Support for advanced rules will be added with subsequent updates." : "Wsparcie dla zaawansowanych zasad będzie wprowadzane sukcesywnie wraz z kolejnymi aktualizacjami.",
    "Reset repeating rule" : "Zresetuj powtarzającą się zasadę",
    "Repeat every ..." : "Powtarzaj każdą...",
    "end repeat ..." : "zakończ powtarzanie...",
    "times" : "razy",
    "Import Calendars" : "Importuj kalendarze",
    "Import canceled" : "Import anulowany",
    "Analyzing calendar" : "Analiza kalendarza",
    "The file contains objects incompatible with the selected calendar" : "Plik zawiera obiekty niekompatybilne z wybranym kalendarzem",
    "New calendar" : "Nowy kalendarz",
    "File is empty" : "Plik jest pusty",
    "Import scheduled" : "Import został zaplanowany",
    "%s shared the calendar <strong>%s</strong> with you" : "%s udostępnił Tobie kalendarz <strong>%s</strong>",
    "Embed" : "Osadź",
    "Iframe to integrate" : "Iframe do osadzenia",
    "Publish URL" : "Publikowanie URL",
    "Settings & import" : "Ustawienia i import",
    "Skip simple event editor" : "Pomiń prosty edytor zdarzeń",
    "Show week numbers" : "Pokaż numery tygodni",
    "Import calendar" : "Importuj kalendarz",
    "No Calendars selected for import" : "Nie wybrano kalendarzy do importu",
    "Primary CalDAV address" : "Podstawowy adres CalDAV",
    "iOS/OS X CalDAV address" : "Adres CalDAV dla iOS/OS X",
    "Subscribe" : "Subskrybuj"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-app-calendar-1.6.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/pl.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendarz",
    "%s has published the calendar »%s«" : "%s opublikował kalendarz »%s«",
    "Hello," : "Witaj,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chcieliśmy poinformować, że %s opublikował kalendarz %s.",
    "Open »%s«" : "Otwórz »%s«",
    "Cheers!" : "Zdrówko!",
    "Recipient" : "Odbiorca",
    "Too many redirects. Aborting ..." : "Za dużo przekierowań. Przerywam...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Brak dostępu do kalendarza na zdalnym serwerze (HTTP {%s} error)",
    "Error connecting to remote server" : "Błąd podczas łączenia się z serwerem zdalnym",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Błąd żądania zasobu na zdalnym serwerze. Możliwe, że może to być związane z niedopasowaniem certyfikatu",
    "Error requesting resource on remote server" : "Błąd żądania zasobów na zdalnym serwerze",
    "Individual" : "Indywidualny",
    "Group" : "Grupa",
    "Resource" : "Zasób",
    "Room" : "Pokój",
    "Unknown" : "Nieznany",
    "Required" : "Wymagany",
    "Optional" : "Opcjonalny",
    "Does not attend" : "Nie uczestniczy",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jesteś w nieznanej strefie czasowej ({tz}), powracam do UTC",
    "Please create a calendar first." : "Proszę najpierw utworzyć kalendarz.",
    "New event" : "Nowe zdarzenie",
    "CalDAV address for clients" : "Adres CalDAV dla klientów",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Niektóre zdarzenia w tym kalendarzu są uszkodzone. Proszę sprawdzić konsole JS, aby dowiedzieć się więcej.",
    "Share Calendar" : "Współdziel kalendarz",
    "Shared" : "Udostępniono",
    "WebDAV address for subscriptions" : "Adres WebDAV dla subskrypcji",
    "group" : "grupa",
    "Details" : "Szczegóły",
    "Attendees" : "Uczestnicy",
    "Reminders" : "Przypomnienia",
    "Repeating" : "Powtarzające się",
    "When shared show full event" : "Kiedy współdzieli pokaż całe wydarzenie",
    "When shared show only busy" : "Kiedy współdzieli pokaż tylko zajęty",
    "When shared hide this event" : "Kiedy współdzieli ukryj to wydarzenie",
    "Confirmed" : "Potwierdzone",
    "Tentative" : "Możliwe",
    "Cancelled" : "Przerwano",
    "Please add a title." : "Dodaj tytuł.",
    "Please select a calendar." : "Wybierz kalendarz.",
    "The event can not end before it starts." : "Wydarzenie nie może kończyć się zanim się rozpocznie.",
    "Global" : "Ogólny",
    "None" : "Brak.",
    "Every day" : "Codziennie",
    "Every week" : "Co tydzień",
    "Every month" : "Co miesiąc",
    "Every year" : "Co roku",
    "never" : "nigdy",
    "after" : "po",
    "How about getting started by importing some calendars?" : "Czy rozpocząć pracę przez importowanie kilku kalendarzy?",
    "At time of event" : "W momencie zdarzenia",
    "5 minutes before" : "5 minut przed",
    "10 minutes before" : "10 minut przed",
    "15 minutes before" : "15 minut przed",
    "30 minutes before" : "30 minut przed",
    "1 hour before" : "1 godzinę przed",
    "2 hours before" : "2 godziny przed",
    "Custom" : "Dowolnie",
    "Audio" : "Dźwięk",
    "Email" : "E-mail",
    "Pop-up" : "Pop-up",
    "sec" : "sek",
    "min" : "min",
    "hours" : "godzin",
    "days" : "dniach",
    "week" : "tydzień",
    "before" : "przed",
    "start" : "rozpocznij",
    "end" : "zakończ",
    "Editing reminders of unknown type not supported." : "Edycja przypomnień nieznanego typu nie jest wspierana.",
    "Week {number} of {year}" : "{number}. tydzień {year}",
    "Successfully imported {imported} objects" : "Pomyślnie zaimportowano {imported} obiektów",
    "Imported {imported} out of {all}, skipped one duplicate" : "Zaimportowano {imported} z {all}, pominięto jeden duplikat",
    "Imported {imported} out of {all}, one failure" : "Zaimportowano {imported} z {all}, z jednym błędem",
    "Imported {imported} out of {all}, {errors} failures" : "Zaimportowano {imported} z {all}, {errors} błędów",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Zaimportowano {imported} z {all}, pominięto {duplicates} duplikatów",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Zaimportowano {imported} z {all}, {errors} błędów, pominięto {duplicates} duplikatów",
    "Audio alarm {time} before the event starts" : "Alarm dźwiękowy {time} przed rozpoczęciem zdarzenia",
    "Pop-up {time} before the event starts" : "Wyskakujące powiadomienie {time} przed rozpoczęciem zdarzenia",
    "Email {time} before the event starts" : "Email {time} przed rozpoczęciem zdarzenia",
    "None {time} before the event starts" : "Brak akcji {time} przed rozpoczęciem zdarzenia",
    "{type} {time} before the event starts" : "{type} {time} przed rozpoczęciem wydarzenia",
    "Audio alarm {time} before the event ends" : "Alarm dźwiękowy {time} przed zakończeniem zdarzenia",
    "Pop-up {time} before the event ends" : "Wyskakujące powiadomienie {time} przed zakończeniem zdarzenia",
    "Email {time} before the event ends" : "Email {time} przed zakończeniem zdarzenia",
    "None {time} before the event ends" : "Brak akcji {time} przed zakończeniem zdarzenia",
    "{type} {time} before the event ends" : "{type} {time} przed zakończeniem wydarzenia",
    "Audio alarm {time} after the event starts" : "Alarm dźwiękowy {time} po rozpoczęciu zdarzenia",
    "Pop-up {time} after the event starts" : "Wyskakujące powiadomienie {time} po rozpoczęciu zdarzenia",
    "Email {time} after the event starts" : "Email {time} po rozpoczęciu zdarzenia",
    "None {time} after the event starts" : "Brak akcji {time} po rozpoczęciu zdarzenia",
    "{type} {time} after the event starts" : "{type} {time} po rozpoczęciu wydarzenia",
    "Audio alarm {time} after the event ends" : "Alarm dźwiękowy {time} po zakończeniu zdarzenia",
    "Pop-up {time} after the event ends" : "Wyskakujące powiadomienie {time} po zakończeniu zdarzenia",
    "Email {time} after the event ends" : "Email {time} po zakończeniu zdarzenia",
    "None {time} after the event ends" : "Brak akcji {time} po zakończeniu zdarzenia",
    "{type} {time} after the event ends" : "{type} {time} po zakończeniu wydarzenia",
    "Audio alarm at the event's start" : "Alarm dźwiękowy podczas rozpoczęcia zdarzenia",
    "Pop-up at the event's start" : "Wyskakujące powiadomienie podczas rozpoczęcia zdarzenia",
    "Email at the event's start" : "Email podczas rozpoczęcia zdarzenia",
    "None at the event's start" : "Brak akcji podczas rozpoczęcia zdarzenia",
    "{type} at the event's start" : "{type} na początku wydarzenia",
    "Audio alarm at the event's end" : "Alarm dźwiękowy podczas zakończenia zdarzenia",
    "Pop-up at the event's end" : "Wyskakujące powiadomienie podczas zakończenia zdarzenia",
    "Email at the event's end" : "Email podczas zakończenia zdarzenia",
    "None at the event's end" : "Brak akcji podczas zakończenia zdarzenia",
    "{type} at the event's end" : "{type} na końcu wydarzenia",
    "Audio alarm at {time}" : "Alarm dźwiękowy o {time}",
    "Pop-up at {time}" : "Wyskakujące powiadomienie o {time}",
    "Email at {time}" : "Email o {time}",
    "None at {time}" : "Brak akcji o {time}",
    "{type} at {time}" : "{type} o {time}",
    "{calendar} shared by {owner}" : "{calendar} współdzielony przez {owner}",
    "Please enter a valid WebCal-URL" : "Wprowadź prawidłowy URL WebCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Poważny błąd proxy w WebCal. Aby uzyskać więcej informacji prosimy o kontakt z administratorem.",
    "Title of the Event" : "Nazwa wydarzenia",
    "Starts" : "Zaczyna się",
    "Ends" : "Kończy się",
    "All day Event" : "Wydarzenie całodniowe",
    "Delete" : "Usuń",
    "Cancel" : "Anuluj",
    "More ..." : "Więcej...",
    "Create" : "Utwórz",
    "Update" : "Aktualizuj",
    "Close" : "Zamknij",
    "Location" : "Lokalizacja",
    "Description" : "Opis",
    "Event status" : "Status zdarzenia",
    "Visibility when sharing" : "Widoczność podczas współdzielenia",
    "Export" : "Eksportuj",
    "%s has published the calendar %s" : "%s opublikował/-a kalendarz %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chcieliśmy poinformować, że %s opublikował/-a kalendarz {boldstart}%s{boldend}.",
    "Click here to access it" : "Kliknij tutaj, aby uzyskać dostęp do niego",
    "We wanted to inform you that %s has published the calendar %s." : "Chcieliśmy poinformować, że %s opublikował/-a kalendarz %s.",
    "Click on the link below to access it" : "Kliknij na link poniżej, aby uzyskać do niego dostęp",
    "Day" : "Dzień",
    "Week" : "Tydzień",
    "Month" : "Miesiąc",
    "Today" : "Dziś",
    "More" : "Więcej",
    "Edit" : "Edytuj",
    "Link" : "Link",
    "iCal link" : "Łącze iCal",
    "Download" : "Pobierz",
    "Share with users or groups" : "Współdziel z grupami bądź użytkownikami",
    "can edit" : "może edytować",
    "Share link" : "Udostępnij link",
    "Public access" : "Dostęp publiczny",
    "Email link to person" : "Wyślij wiadomość do osoby",
    "Send" : "Wysłać",
    "New Calendar" : "Nowy kalendarz",
    "Name" : "Nazwa",
    "New Subscription" : "Nowa subskrypcja",
    "Go back" : "Wróć",
    "Go forward" : "Naprzód",
    "Calendar does not exist" : "Kalendarz nie istnieje",
    "Maybe you got a wrong link or the calendar was unshared?" : "Być może link jest nieprawidłowy lub kalendarz przestał być współdzielony.",
    "Edit event" : "Edytuj zdarzenie",
    "Delete Event" : "Usuń zdarzenie",
    "Save Event" : "Zapisz zdarzenie",
    "Time" : "Czas",
    "Type" : "Typ",
    "Relative" : "Pokrewny",
    "Absolute" : "Całkowity",
    "Repeat" : "Powtarzaj",
    "times every" : "razy w każdy",
    "Add" : "Dodaj",
    "Email address of attendee" : "Adres e-mail uczestnika",
    "Please add your email address in the personal settings in order to add attendees." : "Aby dodać uczestników, proszę ustawić adres e-mail w ustawieniach konta.",
    "from" : "z",
    "to" : "do",
    "This event's repeating rule is not supported yet." : "Ta reguła powtarzania wydarzenia nie jest jeszcze wspierana.",
    "Support for advanced rules will be added with subsequent updates." : "Wsparcie dla zaawansowanych zasad będzie wprowadzane sukcesywnie wraz z kolejnymi aktualizacjami.",
    "Reset repeating rule" : "Zresetuj powtarzającą się zasadę",
    "Repeat every ..." : "Powtarzaj każdą...",
    "end repeat ..." : "zakończ powtarzanie...",
    "times" : "razy",
    "Import Calendars" : "Importuj kalendarze",
    "Import canceled" : "Import anulowany",
    "Analyzing calendar" : "Analiza kalendarza",
    "The file contains objects incompatible with the selected calendar" : "Plik zawiera obiekty niekompatybilne z wybranym kalendarzem",
    "New calendar" : "Nowy kalendarz",
    "File is empty" : "Plik jest pusty",
    "Import scheduled" : "Import został zaplanowany",
    "%s shared the calendar <strong>%s</strong> with you" : "%s udostępnił Tobie kalendarz <strong>%s</strong>",
    "Embed" : "Osadź",
    "Iframe to integrate" : "Iframe do osadzenia",
    "Publish URL" : "Publikowanie URL",
    "Settings & import" : "Ustawienia i import",
    "Skip simple event editor" : "Pomiń prosty edytor zdarzeń",
    "Show week numbers" : "Pokaż numery tygodni",
    "Import calendar" : "Importuj kalendarz",
    "No Calendars selected for import" : "Nie wybrano kalendarzy do importu",
    "Primary CalDAV address" : "Podstawowy adres CalDAV",
    "iOS/OS X CalDAV address" : "Adres CalDAV dla iOS/OS X",
    "Subscribe" : "Subskrybuj"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
